Installing qpageview
====================


This package installs one Python package, ``qpageview``, in the usual location
for Python modules.

You can install qpageview without downloading it first via ``pip``::

    pip install qpageview


You can also install from the source directory::

    python3 setup.py install


